# Copyright (c) 2020 ETH Zurich
#
# SPDX-License-Identifier: BSL-1.0
# Distributed under the Boost Software License, Version 1.0. (See accompanying
# file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

clang_version="11.0.1"
boost_version="1.78.0"
hwloc_version="2.2.0"
spack_compiler="clang@${clang_version}"
spack_arch="cray-cnl7-broadwell"

spack_spec="pika@main arch=${spack_arch} %${spack_compiler} malloc=mimalloc ^boost@${boost_version} ^hwloc@${hwloc_version}"

export MIMALLOC_EAGER_COMMIT_DELAY=0
export MIMALLOC_ALLOW_LARGE_OS_PAGES=1
